@@ -80,6 +80,7 @@ BEGIN {
                       initdebug enabledebug enabledebuglevel
                       printdebug debugcmd
                       $printdebug_when_debuglevel $debugcmd_when_debuglevel
+                      $atext_re $dot_atom_text_re $angle_addr_re
                       $debugprefix *debuglevel *DEBUG
                       shellquote printcmd messagequote
                       $negate_harmful_gitattrs
@@ -120,6 +121,13 @@ our $gdrlast_refprefix = 'debrebase-last';
 our $printdebug_when_debuglevel = 1;
 our $debugcmd_when_debuglevel = 1;
 
+# This is RFC 5322's 'atext'.
+our $atext_re         = qr([[:alnum:]!#$%&'*+\-/=?^_`{|}~])a;
+# This is RFC 5322's 'dot-atom-text' without comments and whitespace.
+our $dot_atom_text_re = qr($atext_re(?:\.|$atext_re)*)a;
+# This is RFC 5322's 'angle-addr' without obsolete syntax.
+our $angle_addr_re = qr(\<($dot_atom_text_re\@$dot_atom_text_re)\>)a;
+
 our (@git) = qw(git);
 
 # these three all go together, only valid after record_maindir
